;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "nucleo-completion" "0.1.10"
  "Nucleo-backed completion style."
  '((emacs "27.1"))
  :url "https://github.com/kn66/nucleo-completion.el"
  :commit "d3e669fbca85966750c520cd80c931bd16a4b03e"
  :revdesc "d3e669fbca85"
  :keywords '("matching" "convenience")
  :authors '(("Nobu" . "https://github.com/kn66"))
  :maintainers '(("Nobu" . "https://github.com/kn66")))
